function    X2v = X2v_sphere(VAR,a,nu,x,y,Wd,data)
% chi square function for a spherical source

% VAR   vector with unknown parameters x0, y0, z0 and P_G
% x0,y0     coordinates of the center of the sphere 
% z0        depth of the center of the sphere (positive downward and
%              defined as distance below the reference surface)
% P_G       dimensionless excess pressure (pressure/shear modulus)
% b     radius of the sphere
% nu    Poisson's ratio
% x,y   data point location
% Wd    weight matrix
% data  deformation data vector

x0 = VAR(1); y0 = VAR(2); z0 = VAR(3); P_G = VAR(4);
[u v w] = mctigue2D(x0,y0,z0,P_G,a,nu,x,y);

model = [u v w]; model = model(:);
r = data - model;                       % residual
X2 = r'*Wd*r;                           % Chi Square - full covariance
p = length(VAR);                        % number of parameters
N = length(data);                       % number of data points
X2v = X2/(N-p);                         % Chi Square per degrees of freedom


