function P = P(h,x)
% INPUT
%
% h     dimensionless source depth
% x     dummy variable
%
% OUTPUT
% P1-P4 are expressions from Appendix A of Fialko et al (2001). Used in the 
% definition of the functions T1 - T4 (see T.m)
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Fialko, Y, Khazan, Y and M. Simons (2001). Deformation due to a 
% pressurized horizontal circular crack in an elastic half-space, with 
% applications to volcano geodesy. Geophys. J. Int., 146, 181190
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

P(1,:) = (12*h^2-x.^2)./(4*h^2+x.^2).^3;                                    % P1(x), pg 189
P(2,:) = log(4*h^2+x.^2) + (8*h^4+2*x.^2*h^2-x.^4)./(4*h^2+x.^2).^2;        % P2(x), pg 189
P(3,:) = 2*(8*h^4-2*x.^2*h^2+x.^4)./(4*h^2+x.^2).^3;                        % P3(x), pg 189
P(4,:) = (4*h^2-x.^2)./(4*h^2+x.^2).^2;                                     % P4(x), pg 189


