function [pN dpN] = legpol(x,N)
% legendre polynomial, Bonnets recursion formula
%
% Reference 
% http://en.wikipedia.org/wiki/Legendre_polynomials
%
% Note
% index n in wiki goes from 0 to N, in MATLAB j goes from 1 to N+1. To
% obtain the right coefficients we introduced j = n+1 -> n = j-1

    P(1,:) = ones(size(x)); dP(1,:) = zeros(size(x));
    P(2,:) = x; 
    for j=2:N                                                               % loop up the recursion relation 
        P(j+1,:) = ((2*j-1)*x.*P(j,:) - (j-1)*P(j-1,:))/j;
         dP(j,:) = (j-1)*(x.*P(j,:) - P(j-1,:))./(x.^2-1);
    end;
    
    pN =  P(N,:);
   dpN = dP(N,:); 