function    X2v = X2v_spheroidTILTv(VAR,a,mu,nu,x,y,Wd,data)
% chi square function for a prolate spheroid
%
% VAR   vector with unknown parameters x0, y0, z0, A, P_G, theta and phi
%
% SOURCE PARAMETERS
% a         semimajor axis
% A         geometric aspect ratio [dimensionless]
% P_G       dimennsionless excess pressure (pressure/shear modulus) 
% x0,y0     surface coordinates of the center of the prolate spheroid
% z0        depth of the center of the sphere (positive downward and
%              defined as distance below the reference surface)
% theta     plunge (dip) angle [deg] [90 = vertical spheroid]
% phi       trend (strike) angle [deg] [0 = aligned to North]
%
% CRUST PARAMETERS
% mu        shear modulus
% nu        Poisson's ratio 
%
% BENCHMARKS
% x,y       benchmark location
% z         depth within the crust (z=0 is the free surface)
% Wd        weight matrix
% data      deformation data vector

x0 = VAR(1); y0 = VAR(2); z0 = VAR(3); A = VAR(4); P_G = VAR(5); theta = 90; phi = 0; 

[~, ~, ~, dwdx dwdy] = yang(x0,y0,z0,a,A,P_G,mu,nu,theta,phi,x,y,0);
model = [dwdx, dwdy]';
%model = sqrt(dwdx.^2 + dwdy.^2); 

r = data - model;                       % residual
X2 = r'*Wd*r;                           % Chi Square - full covariance
p = length(VAR);                        % number of parameters
N = length(data);                       % number of data points
X2v = X2/(N-p);                         % Chi Square per degrees of freedom